"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.throttle = exports.parallel = exports.loadScript = exports.dateFormat = exports.up = void 0;
/**
 * 向父级元素递归搜索
 *
 * @param _el       当前所在元素
 * @param tagName   目标标签名称
 * @param className 目标元素样式类
 * @returns 目标元素，找不到为 null
 */
function up(_el, tagName, className) {
    if (tagName && className)
        throw '只能任选一种参数，不能同时传';
    var el = _el.parentNode;
    tagName = tagName && tagName.toUpperCase();
    while (el) {
        if (tagName && el.tagName == tagName)
            return el;
        if (className && el.className && ~el.className.indexOf(className))
            return el;
        el = el.parentNode;
    }
    return null;
}
exports.up = up;
/**
 * 日期格式化
 * @author meizz
 * @param date  日期，必须为 Date 类型
 * @param fmt   格式模板
 * @returns 格式化后的字符串
 */
function dateFormat(date, fmt) {
    var o = {
        "M+": date.getMonth() + 1,
        "d+": date.getDate(),
        "h+": date.getHours(),
        "m+": date.getMinutes(),
        "s+": date.getSeconds(),
        "q+": Math.floor((date.getMonth() + 3) / 3),
        "S": date.getMilliseconds() // 毫秒   
    };
    if (/(y+)/.test(fmt))
        fmt = fmt.replace(RegExp.$1, (date.getFullYear() + "").substr(4 - RegExp.$1.length));
    for (var k in o)
        if (new RegExp("(" + k + ")").test(fmt)) {
            var obj = (RegExp.$1.length == 1) ? o[k] : ("00" + o[k]).substr(("" + o[k]).length);
            // @ts-ignore
            fmt = fmt.replace(RegExp.$1, obj);
        }
    return fmt;
}
exports.dateFormat = dateFormat;
/**
 * 加载脚本
 *
 * @param url   脚本地址
 * @param id    脚本元素 id，可选的
 * @param cb    回调函数，可选的
 */
function loadScript(url, id, cb) {
    var script = document.createElement("script");
    script.src = url;
    if (cb)
        script.onload = cb;
    if (id)
        script.id = id;
    document.getElementsByTagName("head")[0].appendChild(script);
}
exports.loadScript = loadScript;
/**
 * 并行和串行任务
 *
 * @author https://segmentfault.com/a/1190000013265925
 * @param arr
 * @param finnaly
 */
function parallel(arr, _finally) {
    var fn, index = 0;
    // @ts-ignore
    var statusArr = Array(arr.length).fill().map(function () { return ({ isActive: false, data: null }); });
    var isFinished = function () {
        return statusArr.every(function (item) { return item.isActive === true; });
    };
    var resolve = function (index) {
        return function (data) {
            statusArr[index].data = data;
            statusArr[index].isActive = true;
            var isFinish = isFinished();
            if (isFinish) {
                var datas = statusArr.map(function (item) { return item.data; });
                _finally(datas);
            }
        };
    };
    // @ts-ignore
    while ((fn = arr.shift())) {
        fn(resolve(index)); // 给 resolve 函数追加参数,可以使用 bind 函数实现,这里使用了柯里化
        index++;
    }
}
exports.parallel = parallel;
/**
 * 函数节流
 *
 * @author https://www.cnblogs.com/moqiutao/p/6875955.html
 * @param fn
 * @param delay
 * @param mustRunDelay
 */
function throttle(fn, delay, mustRunDelay) {
    var timer, t_start;
    return function () {
        var _this = this;
        var t_curr = +new Date();
        window.clearTimeout(timer);
        if (!t_start)
            t_start = t_curr;
        if (t_curr - t_start >= mustRunDelay) {
            // @ts-ignore
            fn.apply(this, arguments);
            t_start = t_curr;
        }
        else {
            var args = arguments;
            // @ts-ignore
            timer = window.setTimeout(function () { return fn.apply(_this, args); }, delay);
        }
    };
}
exports.throttle = throttle;
//# sourceMappingURL=base.js.map