"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.errHandle = void 0;
/**
 * 默认的请求配置
 */
var DEFAULT_XHR_CFG = {
    timeout: 3000,
    withCredentials: false
};
var xhr = {
    /**
     * 对象转换为 URL 参数列表，用 & 分隔
     *
     * @param {Object} param JSON 对象
     * @returns URL 参数列表
     */
    toParams: function (param) {
        var result = "";
        for (var name_1 in param) {
            if (typeof param[name_1] != "function")
                result += "&" + name_1 + "=" + encodeURIComponent(param[name_1]);
        }
        return result.substring(1);
    },
    /**
     * 获取 QueryString 的某个参数
     *
     * @param val
     * @returns
   */
    getQuery: function (val) {
        var w = location.hash.indexOf('?');
        var query = location.hash.substring(w + 1);
        var vars = query.split('&');
        for (var i = 0; i < vars.length; i++) {
            var pair = vars[i].split('=');
            if (pair[0] == val)
                return pair[1];
        }
        return '';
    },
    /**
     * XHR GET 请求
     *
     * @param url
     * @param cb
     * @param params
     */
    get: function (url, cb, params, cfg) {
        if (cfg === void 0) { cfg = DEFAULT_XHR_CFG; }
        var xhr = initXhr(cfg);
        if (params != null)
            url += '?' + this.toParams(params);
        xhr.open("GET", url, true);
        xhr.onreadystatechange = function () {
            if (xhr.readyState == 4) {
                if ((xhr.status >= 200 && xhr.status < 300) || xhr.status == 304) {
                    cb && cb(JSON.parse(xhr.responseText));
                }
                else
                    console.error(xhr.responseText);
            }
        };
        xhr.send();
    },
    /**
     * XHR POST 请求
     *
     * @param url
     * @param cb
     * @param params
     */
    post: function (url, cb, params, cfg) {
        if (cfg === void 0) { cfg = DEFAULT_XHR_CFG; }
        var xhr = initXhr(cfg);
        xhr.open("POST", url, true);
        xhr.onreadystatechange = function () {
            if (xhr.readyState == 4) {
                if ((xhr.status >= 200 && xhr.status < 300) || xhr.status == 304) {
                    cb && cb(JSON.parse(xhr.responseText));
                }
                else
                    errHandle(xhr);
            }
        };
        // 此方法必须在 open()方法和 send() 之间调用
        if (!cfg.contentType) // 如未设置，默认为表单请求
            xhr.setRequestHeader("Content-Type", "application/x-www-form-urlencoded");
        var _params;
        if (typeof params != 'string')
            _params = this.toParams(params);
        else
            _params = params;
        xhr.send(_params);
    },
    /**
    * XHR PUT 请求
    *
    * @param url
    * @param cb
    * @param params
    */
    put: function (url, cb, params, cfg) {
        if (cfg === void 0) { cfg = DEFAULT_XHR_CFG; }
        var xhr = initXhr(cfg);
        xhr.open("PUT", url, true);
        xhr.onreadystatechange = function () {
            if (xhr.readyState == 4) {
                if ((xhr.status >= 200 && xhr.status < 300) || xhr.status == 304) {
                    cb && cb(JSON.parse(xhr.responseText));
                }
                else
                    console.error(xhr.responseText);
            }
        };
        xhr.setRequestHeader("Content-Type", "application/x-www-form-urlencoded");
        var _params;
        if (typeof params != 'string')
            _params = this.toParams(params);
        else
            _params = params;
        xhr.send(_params);
    },
    /**
    * XHR GET 请求
    *
    * @param url
    * @param cb
    * @param params
    */
    dele: function (url, cb, params, cfg) {
        if (cfg === void 0) { cfg = DEFAULT_XHR_CFG; }
        var xhr = initXhr(cfg);
        if (params != null)
            url += '?' + this.toParams(params);
        xhr.open("DELETE", url, true);
        xhr.onreadystatechange = function (e) {
            if (xhr.readyState == 4) {
                if ((xhr.status >= 200 && xhr.status < 300) || xhr.status == 304) {
                    cb && cb(JSON.parse(xhr.responseText));
                }
                else
                    console.error(xhr.responseText);
            }
        };
        xhr.send();
    },
};
/**
 * 初始化 XHR
 *
 * @param cfg
 * @returns
 */
function initXhr(cfg) {
    var xhr = new XMLHttpRequest();
    if (cfg && cfg.timeout) {
        xhr.timeout = cfg.timeout;
        xhr.ontimeout = function (e) { alert('系统异常，XHR 连接服务超时'); };
    }
    if (cfg && cfg.withCredentials)
        xhr.withCredentials = true;
    return xhr;
}
/**
 *
 * @param xhr
 */
function errHandle(xhr) {
    var msg;
    if (xhr.status <= 400) {
        msg = '请求参数错误或者权限不足。';
    }
    else if (xhr.status <= 500) {
        msg = '服务端异常。';
    }
    else
        msg = "\u672A\u77E5\u5F02\u5E38\uFF0CHTTP code:" + xhr.status + "\u3002";
    if (!xhr.responseText)
        msg += " 服务端返回空的字符串！";
    console.error(msg, xhr.responseText);
    alert(msg);
}
exports.errHandle = errHandle;
// export default xhr;
//# sourceMappingURL=xhr.js.map